Index: include/v8-profiler.h |
diff --git a/include/v8-profiler.h b/include/v8-profiler.h |
index f2128ce0bed6bb35ebcbdca72cfd6e56d892f892..e538f4a84068e6836567453eddb1b00b7d0ccbd4 100644 |
--- a/include/v8-profiler.h |
+++ b/include/v8-profiler.h |
@@ -61,20 +61,27 @@ class V8_EXPORT CpuProfileNode { |
* Returns total (self + children) execution time of the function, |
* in milliseconds, estimated by samples count. |
*/ |
- double GetTotalTime() const; |
+ V8_DEPRECATED(double GetTotalTime() const); |
/** |
* Returns self execution time of the function, in milliseconds, |
* estimated by samples count. |
*/ |
- double GetSelfTime() const; |
+ V8_DEPRECATED(double GetSelfTime() const); |
/** Returns the count of samples where function exists. */ |
- double GetTotalSamplesCount() const; |
+ V8_DEPRECATED(double GetTotalSamplesCount() const); |
- /** Returns the count of samples where function was currently executing. */ |
+ /** DEPRECATED. Please use GetHitCount instead. |
+ * Returns the count of samples where function was currently executing. |
+ */ |
double GetSelfSamplesCount() const; |
Sven Panne
2013/08/08 13:05:38
Can't we use V8_DEPRECATED here?
yurys
2013/08/08 13:37:41
We need to change Chrome DevTools to use the new G
|
+ /** |
+ * Returns the count of samples where the function was currently executing. |
+ */ |
+ unsigned GetHitCount() const; |
+ |
/** Returns function entry UID. */ |
unsigned GetCallUid() const; |